==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Edit/DrawingPreferences/DimensionSettings/ts/DimensionSettings_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>DimensionSettings</name>
    <message>
        <location filename="../DimensionSettings.js" line="+27"/>
        <source>Defaults for New Drawings</source>
        <translatorcomment>--ignored case--
--file: qcadguiqt_pl.ts--
Domyślne dla nowych rysunków</translatorcomment>
        <translation type="unfinished">Domyślne dla nowych rysunków</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+2"/>
        <source>Dimension Settings</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Ustawienia wymiarowe</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Dimension</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
Wymi&amp;ar
Wymiar
Wskaż położenie linii wymiarowej</translatorcomment>
        <translation type="unfinished">Wymiar</translation>
    </message>
    <message>
        <location line="+107"/>
        <source>Scientific</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Naukowy</translatorcomment>
        <translation type="unfinished">Naukowy</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Decimal</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Dziesiętny
Stopnie dziesiętne</translatorcomment>
        <translation type="unfinished">Dziesiętny</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Engineering</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Inżynierski
Dla formatu długości &quot;Inżynierski&quot; i &quot;Architektoniczny&quot;,jednostka musi byc ustawiona na cale.</translatorcomment>
        <translation type="unfinished">Inżynierski</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Architectural</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Architektoniczny
Dla formatu długości &quot;Inżynierski&quot; i &quot;Architektoniczny&quot;,jednostka musi byc ustawiona na cale.</translatorcomment>
        <translation type="unfinished">Architektoniczny</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fractional</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Ułamkowy</translatorcomment>
        <translation type="unfinished">Ułamkowy</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Decimal Degrees</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Stopnie dziesiętne</translatorcomment>
        <translation type="unfinished">Stopnie dziesiętne</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Deg/min/sec</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Stopnie/minuty/sekundy</translatorcomment>
        <translation type="unfinished">Stopnie/minuty/sekundy</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gradians</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Gradusy</translatorcomment>
        <translation type="unfinished">Gradusy</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Radians</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Radiany
Gradusy</translatorcomment>
        <translation type="unfinished">Radiany</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Surveyor&apos;s units</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Jednostki geometryczne</translatorcomment>
        <translation type="unfinished">Jednostki geometryczne</translation>
    </message>
    <message>
        <location line="+198"/>
        <source>Unit / Format</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Jednostka / Format</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The drawing unit must be &apos;Inch&apos; or &apos;Foot&apos; to display dimension labels in formats &apos;Architectural&apos; or &apos;Engineering&apos;. Format changed to &apos;Decimal&apos;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The drawing unit must be &apos;Inch&apos; to display dimension labels in formats &apos;Architectural&apos; or &apos;Engineering&apos;. Format changed to &apos;Decimal&apos;.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Jednostka rysunek musi być &quot;Cal&amp;quot;, aby wyświetlać etykiety rozmiarom w formatach &amp;quot;Architektonicznych&amp;quot; lub &amp;quot;inżynieria&amp;quot;. Format zmieniony na &amp;quot;Decimal&amp;quot;.</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+29"/>
        <source>Sizes</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Zmienia rozmiar okna aplikacji
Rozmiary</translatorcomment>
        <translation type="unfinished">Rozmiary</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Keep proportions</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Zachowaj proporcje</translatorcomment>
        <translation type="unfinished">Zachowaj proporcje</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Text height:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wysokość tekstu:</translatorcomment>
        <translation type="unfinished">Wysokość tekstu:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Extension line offset:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Przesunięcie linii rozszerzenia:</translatorcomment>
        <translation type="unfinished">Przesunięcie linii rozszerzenia:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Extension line extension:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Rozszerzenie linii rozszerzenia:</translatorcomment>
        <translation type="unfinished">Rozszerzenie linii rozszerzenia:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Dimension line gap:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Przerwa linii wymiarowej:</translatorcomment>
        <translation type="unfinished">Przerwa linii wymiarowej:</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Arrow size:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Rozmiar strzałki:</translatorcomment>
        <translation type="unfinished">Rozmiar strzałki:</translation>
    </message>
    <message>
        <location line="+95"/>
        <source>Size scale factor:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+38"/>
        <source>Arrow Style</source>
        <translatorcomment>--google--
Styl strzałki:
Styl strzałki</translatorcomment>
        <translation type="unfinished">Styl strzałki</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Arrow</source>
        <translatorcomment>--exact match--
--file: designer_pl.ts--
Odnośnik (linia ze strzałką)
Rozmiar strzałki:</translatorcomment>
        <translation type="unfinished">Strzałka</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Architectural Tick</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Strzałka architektoniczna</translatorcomment>
        <translation type="unfinished">Strzałka architektoniczna</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Dimension label font:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Label Format</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Format etykiet</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Linear Dimensions</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Wymiarów liniowych</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Format:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Format:</translatorcomment>
        <translation type="unfinished">&amp;Format:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>P&amp;recision:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Dokładność:</translatorcomment>
        <translation type="unfinished">&amp;Dokładność:</translation>
    </message>
    <message>
        <location line="+32"/>
        <location line="+60"/>
        <source>Show trailing zeros</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Pokaż końcowe zera</translatorcomment>
        <translation type="unfinished">Pokaż końcowe zera</translation>
    </message>
    <message>
        <location line="-50"/>
        <source>Angular Dimensions</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Wymiary kątowe</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>F&amp;ormat:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
F&amp;ormat:</translatorcomment>
        <translation type="unfinished">F&amp;ormat:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Pre&amp;cision:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Dokładność:</translatorcomment>
        <translation type="unfinished">&amp;Dokładność:</translation>
    </message>
    <message>
        <location line="+32"/>
        <location line="+19"/>
        <source>Preview</source>
        <translatorcomment>--exact match--
--file: qtconfig_pl.ts--
Podgląd wydruku dla %1
Podgląd wydruku
Pokazuje podgląd wydruku</translatorcomment>
        <translation type="unfinished">Podgląd</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Edit/DrawingPreferences/DimensionSettings/ts/DimensionSettings_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>DimensionSettings</name>
    <message>
        <location filename="../DimensionSettings.js" line="+27"/>
        <source>Defaults for New Drawings</source>
        <translatorcomment>--ignored case--
--file: qcadguiqt_pl.ts--
Domyślne dla nowych rysunków</translatorcomment>
        <translation>Domyślne dla nowych rysunków</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+2"/>
        <source>Dimension Settings</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Wymiary</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Dimension</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
Wymi&amp;ar
Wymiar
Wskaż położenie linii wymiarowej</translatorcomment>
        <translation>Wymiar</translation>
    </message>
    <message>
        <location line="+108"/>
        <source>point</source>
        <translation>kropka</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>comma</source>
        <translation>przecinek</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>space</source>
        <translation>odstęp</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Scientific</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Naukowy</translatorcomment>
        <translation>Naukowy</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Decimal</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Dziesiętny
Stopnie dziesiętne</translatorcomment>
        <translation>Dziesiętny</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Engineering</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Inżynierski
Dla formatu długości &quot;Inżynierski&quot; i &quot;Architektoniczny&quot;,jednostka musi byc ustawiona na cale.</translatorcomment>
        <translation>Inżynierski</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Architectural</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Architektoniczny
Dla formatu długości &quot;Inżynierski&quot; i &quot;Architektoniczny&quot;,jednostka musi byc ustawiona na cale.</translatorcomment>
        <translation>Architektoniczny</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fractional</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Ułamkowy</translatorcomment>
        <translation>Ułamkowy</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Decimal Degrees</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Stopnie dziesiętne</translatorcomment>
        <translation>Stopnie dziesiętne</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Deg/min/sec</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Stopnie/minuty/sekundy</translatorcomment>
        <translation>Stopnie/minuty/sekundy</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gradians</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Gradusy</translatorcomment>
        <translation>Gradusy</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Radians</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Radiany
Gradusy</translatorcomment>
        <translation>Radiany</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Surveyor&apos;s units</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Jednostki geometryczne</translatorcomment>
        <translation>Jednostki geometryczne</translation>
    </message>
    <message>
        <location line="+209"/>
        <source>Unit / Format</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Jednostka / format</translation>
    </message>
    <message>
        <source>The drawing unit must be &apos;Inch&apos; or &apos;Foot&apos; to display dimension labels in formats &apos;Architectural&apos; or &apos;Engineering&apos;. Format changed to &apos;Decimal&apos;.</source>
        <translation type="vanished">Aby wyświetlać etykiety wymiarów w formacie „architektonicznym” lub „inżynierskim”, jednostką rysunku musi być „cal” lub „stopa”. Zmieniono format na „dziesiętny”.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The drawing unit must be &apos;Inch&apos; to display dimension labels in formats &apos;Architectural&apos; or &apos;Engineering&apos;. Format changed to &apos;Decimal&apos;.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Aby wyświetlać etykiety wymiarów w formacie „architektonicznym” lub „inżynierskim”, jednostką rysunku musi być „cal”. Zmieniono format na „dziesiętny”.</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+29"/>
        <source>Sizes</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Zmienia rozmiar okna aplikacji
Rozmiary</translatorcomment>
        <translation>Rozmiary</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Keep proportions</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Zachowaj proporcje</translatorcomment>
        <translation>Zachowanie proporcji</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Text height:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wysokość tekstu:</translatorcomment>
        <translation>Wysokość tekstu:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Extension line offset:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Przesunięcie linii rozszerzenia:</translatorcomment>
        <translation>Przesunięcie linii pomocniczej:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Extension line extension:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Rozszerzenie linii rozszerzenia:</translatorcomment>
        <translation>Wydłużenie linii pomocniczej:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Dimension line gap:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Przerwa linii wymiarowej:</translatorcomment>
        <translation>Odstęp linii wymiarowej:</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Arrow size:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Rozmiar strzałki:</translatorcomment>
        <translation>Rozmiar strzałki:</translation>
    </message>
    <message>
        <location line="+95"/>
        <source>Size scale factor:</source>
        <translation>Współczynnik skali:</translation>
    </message>
    <message>
        <location line="+38"/>
        <source>Arrow Style</source>
        <translatorcomment>--google--
Styl strzałki:
Styl strzałki</translatorcomment>
        <translation>Styl strzałki</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Arrow</source>
        <translatorcomment>--exact match--
--file: designer_pl.ts--
Odnośnik (linia ze strzałką)
Rozmiar strzałki:</translatorcomment>
        <translation>Strzałka</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Architectural Tick</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Strzałka architektoniczna</translatorcomment>
        <translation>Zasieczka</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Font</source>
        <translation>Czcionka</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Dimension label font:</source>
        <translation>Czcionka etykiet wymiarów</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Number Format</source>
        <translation>Format liczb</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Decimal separator:</source>
        <translation>Separator dziesiętny:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Label Format</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Format etykiet</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Linear Dimensions</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Wymiary liniowe</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Format:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Format:</translatorcomment>
        <translation>&amp;Format:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>P&amp;recision:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Dokładność:</translatorcomment>
        <translation>&amp;Dokładność:</translation>
    </message>
    <message>
        <location line="+32"/>
        <location line="+60"/>
        <source>Show trailing zeros</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Pokaż końcowe zera</translatorcomment>
        <translation>Wyświetlanie końcowych zer</translation>
    </message>
    <message>
        <location line="-50"/>
        <source>Angular Dimensions</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Wymiary kątowe</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>F&amp;ormat:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
F&amp;ormat:</translatorcomment>
        <translation>F&amp;ormat:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Pre&amp;cision:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Dokładność:</translatorcomment>
        <translation>&amp;Dokładność:</translation>
    </message>
    <message>
        <location line="+32"/>
        <location line="+19"/>
        <source>Preview</source>
        <translatorcomment>--exact match--
--file: qtconfig_pl.ts--
Podgląd wydruku dla %1
Podgląd wydruku
Pokazuje podgląd wydruku</translatorcomment>
        <translation>Podgląd</translation>
    </message>
</context>
</TS>
